@@ -1,89 +1,13 @@
-# Alien::Libjio
-#  A Perl package to install libjio, a library for Journalled I/O.
-#
-# $Id: Libjio.pm 9520 2009-10-04 03:58:25Z FREQUENCY@cpan.org $
-
 package Alien::Libjio;
+BEGIN {
+  $Alien::Libjio::VERSION = '1.004';
+}
+# ABSTRACT: Utility package to install and locate libjio
 
 use strict;
 use warnings;
 use Carp ();
 
-=head1 NAME
-
-Alien::Libjio - Utility package to install and locate libjio
-
-=head1 VERSION
-
-Version 1.003 ($Id: Libjio.pm 9520 2009-10-04 03:58:25Z FREQUENCY@cpan.org $)
-
-=cut
-
-our $VERSION = '1.003';
-$VERSION = eval $VERSION;
-
-=head1 DESCRIPTION
-
-To ensure reliability, some file systems and databases provide support for
-something known as journalling. The idea is to ensure data consistency by
-creating a log of actions to be taken (called a Write Ahead Log) before
-committing them to disk. That way, if a transaction were to fail due to a
-system crash or other unexpected event, the write ahead log could be used to
-finish writing the data.
-
-While this functionality is often available with networked databases, it can
-be a rather memory- and processor-intensive solution, even where reliable
-writes are important. In other cases, the filesystem does not provide native
-journalling support, so other tricks may be used to ensure data integrity,
-such as writing to a separate temporary file and then overwriting the file
-instead of modifying it in-place. Unfortunately, this method cannot handle
-threaded operations appropriately.
-
-Thankfully, Alberto Bertogli published a userspace C library called libjio
-that can provide these features in a small (less than 1500 lines of code)
-library with no external dependencies.
-
-This package is designed to install it, and provide a way to get the flags
-necessary to compile programs using it. It is particularly useful for Perl XS
-programs that use it, such as B<IO::Journal>.
-
-=head1 SYNOPSIS
-
-  use Alien::Libjio;
-
-  my $jio = Alien::Libjio->new;
-  my $ldflags = $jio->ldflags;
-  my $cflags = $jio->cflags;
-
-=head1 COMPATIBILITY
-
-This module was tested under Perl 5.10.0, using Debian Linux. However, because
-it's Pure Perl and doesn't do anything too obscure, it should be compatible
-with any version of Perl that supports its prerequisite modules.
-
-By default, this library is installed wherever the main system libraries are
-usually installed. As a result, C<Alien::Libjio> will only work if installed
-with root permissions.
-
-If you encounter any problems on a different version or architecture, please
-contact the maintainer.
-
-=head1 METHODS
-
-=head2 Alien::Libjio->new
-
-Creates a new C<Alien::Libjio> object, which essentially just has a few
-convenience methods providing useful information like compiler and linker
-flags.
-
-Example code:
-
-  my $jio = Alien::Libjio->new();
-
-This method will return an appropriate B<Alien::Libjio> object or throw an
-exception on error.
-
-=cut
 
 sub new {
   my ($class, @seed) = @_;
@@ -103,16 +27,6 @@ sub new {
   return $self;
 }
 
-=head2 $jio->installed
-
-Determine if a valid installation of libjio has been detected in the system.
-This method will return a true value if it is, or undef otherwise.
-
-Example code:
-
-  print "okay\n" if $jio->installed;
-
-=cut
 
 sub installed {
   my ($self) = @_;
@@ -122,18 +36,6 @@ sub installed {
   return $self->{installed};
 }
 
-=head2 $jio->version
-
-Determine the installed version of libjio, as a string.
-
-Currently versions are simply floating-point numbers, so you can treat the
-version number as such, but this behaviour is subject to change.
-
-Example code:
-
-  my $version = $jio->version;
-
-=cut
 
 sub version {
   my ($self) = @_;
@@ -143,27 +45,6 @@ sub version {
   return $self->{version};
 }
 
-=head2 $jio->ldflags
-
-=head2 $jio->linker_flags
-
-This returns the flags required to link C code with the local installation of
-libjio (typically in the LDFLAGS variable). It is particularly useful for
-building and installing Perl XS modules such as L<IO::Journal>.
-
-In scalar context, it returns an array reference suitable for passing to
-other build systems, particularly L<Module::Build>. In list context, it gives
-a normal array so that C<join> and friends will work as expected.
-
-Example code:
-
-  my $ldflags = $jio->ldflags;
-  my @ldflags = @{ $jio->ldflags };
-  my $ldstring = join(' ', $jio->ldflags);
-  # or:
-  # my $ldflags = $jio->linker_flags;
-
-=cut
 
 sub ldflags {
   my ($self) = @_;
@@ -182,23 +63,6 @@ sub ldflags {
 # Glob to create an alias to ldflags
 *linker_flags = *ldflags;
 
-=head2 $jio->cflags
-
-=head2 $jio->compiler_flags
-
-This method returns the compiler option flags to compile C code which uses
-the libjio library (typically in the CFLAGS variable). It is particularly
-useful for building and installing Perl XS modules such as L<IO::Journal>.
-
-Example code:
-
-  my $cflags = $jio->cflags;
-  my @cflags = @{ $jio->cflags };
-  my $ccstring = join(' ', $jio->cflags);
-  # or:
-  # my $cflags = $jio->compiler_flags;
-
-=cut
 
 sub cflags {
   my ($self) = @_;
@@ -215,32 +79,6 @@ sub cflags {
 }
 *compiler_flags = *cflags;
 
-=head2 $jio->method
-
-=head2 $jio->how
-
-This method returns the method the module used to find information about
-libjio. The following methods are currently used (in priority order):
-
-=over
-
-=item *
-
-pkg-config: the de-facto package information tool
-
-=item *
-
-ExtUtils::Liblist: a utility module used by ExtUtils::MakeMaker
-
-=back
-
-Example code:
-
-  if ($jio->installed) {
-    print 'I found this information using: ', $jio->how, "\n";
-  }
-
-=cut
 
 sub method {
   my ($self) = @_;
@@ -349,13 +187,146 @@ sub _try_liblist {
   return 1;
 }
 
-=head1 AUTHOR
 
-Jonathan Yu E<lt>jawnsy@cpan.orgE<gt>
+__END__
+=pod
 
-=head2 CONTRIBUTORS
+=head1 NAME
 
-Your name here ;-)
+Alien::Libjio - Utility package to install and locate libjio
+
+=head1 VERSION
+
+version 1.004
+
+=head1 SYNOPSIS
+
+  use Alien::Libjio;
+
+  my $jio = Alien::Libjio->new;
+  my $ldflags = $jio->ldflags;
+  my $cflags = $jio->cflags;
+
+=head1 DESCRIPTION
+
+To ensure reliability, some file systems and databases provide support for
+something known as journalling. The idea is to ensure data consistency by
+creating a log of actions to be taken (called a Write Ahead Log) before
+committing them to disk. That way, if a transaction were to fail due to a
+system crash or other unexpected event, the write ahead log could be used to
+finish writing the data.
+
+While this functionality is often available with networked databases, it can
+be a rather memory- and processor-intensive solution, even where reliable
+writes are important. In other cases, the filesystem does not provide native
+journalling support, so other tricks may be used to ensure data integrity,
+such as writing to a separate temporary file and then overwriting the file
+instead of modifying it in-place. Unfortunately, this method cannot handle
+threaded operations appropriately.
+
+Thankfully, Alberto Bertogli published a userspace C library called libjio
+that can provide these features in a small (less than 1500 lines of code)
+library with no external dependencies.
+
+This package is designed to install it, and provide a way to get the flags
+necessary to compile programs using it. It is particularly useful for Perl XS
+programs that use it, such as B<IO::Journal>.
+
+=head1 METHODS
+
+=head2 Alien::Libjio->new
+
+Creates a new C<Alien::Libjio> object, which essentially just has a few
+convenience methods providing useful information like compiler and linker
+flags.
+
+Example code:
+
+  my $jio = Alien::Libjio->new();
+
+This method will return an appropriate B<Alien::Libjio> object or throw an
+exception on error.
+
+=head2 $jio->installed
+
+Determine if a valid installation of libjio has been detected in the system.
+This method will return a true value if it is, or undef otherwise.
+
+Example code:
+
+  print "okay\n" if $jio->installed;
+
+=head2 $jio->version
+
+Determine the installed version of libjio, as a string.
+
+Currently versions are simply floating-point numbers, so you can treat the
+version number as such, but this behaviour is subject to change.
+
+Example code:
+
+  my $version = $jio->version;
+
+=head2 $jio->ldflags
+
+=head2 $jio->linker_flags
+
+This returns the flags required to link C code with the local installation of
+libjio (typically in the LDFLAGS variable). It is particularly useful for
+building and installing Perl XS modules such as L<IO::Journal>.
+
+In scalar context, it returns an array reference suitable for passing to
+other build systems, particularly L<Module::Build>. In list context, it gives
+a normal array so that C<join> and friends will work as expected.
+
+Example code:
+
+  my $ldflags = $jio->ldflags;
+  my @ldflags = @{ $jio->ldflags };
+  my $ldstring = join(' ', $jio->ldflags);
+  # or:
+  # my $ldflags = $jio->linker_flags;
+
+=head2 $jio->cflags
+
+=head2 $jio->compiler_flags
+
+This method returns the compiler option flags to compile C code which uses
+the libjio library (typically in the CFLAGS variable). It is particularly
+useful for building and installing Perl XS modules such as L<IO::Journal>.
+
+Example code:
+
+  my $cflags = $jio->cflags;
+  my @cflags = @{ $jio->cflags };
+  my $ccstring = join(' ', $jio->cflags);
+  # or:
+  # my $cflags = $jio->compiler_flags;
+
+=head2 $jio->method
+
+=head2 $jio->how
+
+This method returns the method the module used to find information about
+libjio. The following methods are currently used (in priority order):
+
+=over
+
+=item *
+
+pkg-config: the de-facto package information tool
+
+=item *
+
+ExtUtils::Liblist: a utility module used by ExtUtils::MakeMaker
+
+=back
+
+Example code:
+
+  if ($jio->installed) {
+    print 'I found this information using: ', $jio->how, "\n";
+  }
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -368,63 +339,6 @@ developing this useful library and for releasing it into the public domain.
 
 =back
 
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Alien::Libjio
-
-You can also look for information at:
-
-=over
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Alien-Libjio>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Alien-Libjio>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Alien-Libjio>
-
-=item * CPAN Request Tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Alien-Libjio>
-
-=item * CPAN Testing Service (Kwalitee Tests)
-
-L<http://cpants.perl.org/dist/overview/Alien-Libjio>
-
-=item * CPAN Testers Platform Compatibility Matrix
-
-L<http://cpantesters.org/show/Alien-Libjio.html>
-
-=back
-
-=head1 REPOSITORY
-
-You can access the most recent development version of this module at:
-
-L<http://svn.ali.as/cpan/trunk/Alien-Libjio>
-
-If you are a CPAN developer and would like to make modifications to the code
-base, please contact Adam Kennedy E<lt>adamk@cpan.orgE<gt>, the repository
-administrator. I only ask that you contact me first to discuss the changes you
-wish to make to the distribution.
-
-=head1 FEEDBACK
-
-Please send relevant comments, rotten tomatoes and suggestions directly to the
-maintainer noted above.
-
-If you have a bug report or feature request, please file them on the CPAN
-Request Tracker at L<http://rt.cpan.org>. If you are able to submit your bug
-report in the form of failing unit tests, you are B<strongly> encouraged to do
-so.
-
 =head1 SEE ALSO
 
 L<IO::Journal>, a Perl module that provides an interface to libjio.
@@ -434,12 +348,6 @@ which explains the purpose and features of libjio.
 
 =head1 CAVEATS
 
-=head2 KNOWN BUGS
-
-There are no known bugs as of this release.
-
-=head2 LIMITATIONS
-
 =over
 
 =item *
@@ -450,7 +358,7 @@ installation on your system, but it cannot predict where files might have
 been installed. As a result, this package might install a duplicate copy
 of libjio.
 
-=item  *
+=item *
 
 There is currently no way to save a custom library installation path for
 libjio. This is likely to change in the future.
@@ -466,26 +374,31 @@ Another workaround is to disable taint checking, but that's not recommended.
 
 =back
 
-=head1 LICENSE
+1;
 
-In a perfect world, I could just say that this package and all of the code
-it contains is Public Domain. It's a bit more complicated than that; you'll
-have to read the included F<LICENSE> file to get the full details.
+=head1 BUGS
 
-=head1 QUALITY ASSURANCE METRICS
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=Alien-Libjio
 
-=head2 TEST COVERAGE
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
-  ----------------------- ------ ------ ------ ------ ------ ------
-  File                     stmt   bran   cond   sub    pod   total
-  ----------------------- ------ ------ ------ ------ ------ ------
-  Alien/Libjio.pm         97.7   84.4   66.7   100.0  100.0  93.4
+=head1 AUTHOR
 
-Okay, granted, the coverage sucks -- generally, I aim for 100% in all of
-the categories, using fault injection to test all the code paths. Due to
-the nature of the module it's somewhat difficult to do.
+Jonathan Yu <jawnsy@cpan.org>
 
-=head1 DISCLAIMER OF WARRANTY
+=head1 COPYRIGHT AND LICENSE
+
+Legally speaking, this package and its contents are:
+
+  Copyright (c) 2011 by Jonathan Yu <jawnsy@cpan.org>.
+
+But this is really just a legal technicality that allows the author to
+offer this package under the public domain and also a variety of licensing
+options. For all intents and purposes, this is public domain software,
+which means you can do whatever you want with it.
 
 The software is provided "AS IS", without warranty of any kind, express or
 implied, including but not limited to the warranties of merchantability,
@@ -497,4 +410,3 @@ the software.
 
 =cut
 
-1;
