@@ -9,8 +9,8 @@
 #include <sys/types.h>	/* for ssize_t and off_t */
 #include <stdint.h>	/* for uint*_t */
 #include <sys/uio.h>	/* for struct iovec */
+#include <pthread.h>	/* pthread_mutex_t */
 
-#include "libjio.h"	/* for struct jfs */
 #include "fiu-local.h"	/* for fault injection functions */
 
 #define _F_READ		0x00001
